<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Εντοπίστηκε περιβάλλον live. Παρακαλώ επιλέξτε το διαμέρισμα root
που θέλετε να τροποποιήσετε (εμφανίζονται μόνο διαμερίσματα Linux)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>Εντάξει</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Άκυρο</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Χρήση απλοποιημένης δομής μενού, χωρίς υπομενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Χρήση απλών μενού (χωρίς υπομενού)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Εκκίνηση σε</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Ρύθμιση στο &apos;0&apos; για άμεση εκκίνηση χωρίς να εμφανίζεται το μενού ή στο &apos;-1&apos; για επ &apos;αόριστον παραμονή στο μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Διάρκεια εμφάνισης μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Παράμετροι πυρήνα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Με ενεργοποιημένη αυτή την επιλογή, όποια καταχώρηση επιλέξετε από το μενού εκκίνησης του grub, θα αποθηκευτεί ως η νέα προεπιλογή εκκίνησης στο μέλλον</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Αποθήκευση της τελευταίας επιλογής εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation>Διαχείριση ρυθμίσεων εκκίνησης UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Φόντο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Εικόνα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Ενεργοποίηση θέματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Αρχική οθόνη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Μηνύματα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Πολύ αναλυτικά</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Αναλυτικά (προεπιλεγμένη ρύθμιση)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Περιορισμένα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Εμφάνιση αρχείου καταγραφής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Εμφάνιση βοήθειας </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Περί της εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Περί...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Still running</source>
        <translation>Ακόμα τρέχει</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Set timeout</source>
        <translation>Ορισμός χρονικής διάρκειας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Timeout in seconds:</source>
        <translation>Χρονική διάρκεια σε δευτερόλεπτα:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="618"/>
        <location filename="../mainwindow.cpp" line="1436"/>
        <source>Timeout: %1 seconds</source>
        <translation>Χρονική διάρκεια: %1 δευτερόλεπτα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <location filename="../mainwindow.cpp" line="620"/>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>Boot Next: %1</source>
        <translation>Επόμενη εκκίνηση: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Removal confirmation</source>
        <translation>Επιβεβαίωση αφαίρεσης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation>Θέλετε σίγουρα να διαγράψετε την καταχώρηση εκκίνησης;
%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>Select EFI file</source>
        <translation>Επιλογή αρχείου EFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="406"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation>Αρχεία EFI (*.efi *.EFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <location filename="../mainwindow.cpp" line="433"/>
        <location filename="../mainwindow.cpp" line="519"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <location filename="../mainwindow.cpp" line="603"/>
        <location filename="../mainwindow.cpp" line="703"/>
        <location filename="../mainwindow.cpp" line="792"/>
        <location filename="../mainwindow.cpp" line="1636"/>
        <location filename="../mainwindow.cpp" line="1649"/>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation>Δεν βρέθηκε σημείο προσάρτησης για το %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Set name</source>
        <translation>Ορισμός ονόματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation>Εισαγωγή ονόματος για το μενού UEFI:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Something went wrong, could not add entry.</source>
        <translation>Κάτι πήγε λάθος, δεν προστέθηκε η καταχώρηση.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Εγκατάσταση αρχικής οθόνης εκκίνησης, παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="515"/>
        <source>Updating sources</source>
        <translation>Ενημέρωση πηγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Could not install the bootsplash.</source>
        <translation>Δεν ήταν δυνατή η εγκατάσταση της αρχικής οθόνης εκκίνησης.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="603"/>
        <source>Failed to get UEFI boot entries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Boot Current: %1</source>
        <translation>Τρέχουσα εκκίνηση: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>Could not create a temporary folder</source>
        <translation>Δεν κατέστη δυνατή η δημιουργία προσωρινού φακέλου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <location filename="../mainwindow.cpp" line="732"/>
        <source>Cannot continue</source>
        <translation>Δεν μπορεί να συνεχιστεί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Cannot open LUKS device. Exiting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Δεν μπορεί να δημιουργηθεί περιβάλλον chroot, δεν μπορεί να γίνει αλλαγή στις επιλογές εκκίνησης. Έξοδος...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="792"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation>Κάτι πήγε λάθος, δεν αποθηκεύτηκε η σειρά εκκίνησης.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1078"/>
        <location filename="../mainwindow.cpp" line="1556"/>
        <source>Updating configuration, please wait</source>
        <translation>Ενημέρωση ρυθμίσεων, παρακαλώ περιμένετε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1149"/>
        <source>Updating initramfs...</source>
        <translation>Ενημέρωση initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1163"/>
        <location filename="../mainwindow.cpp" line="1571"/>
        <source>Updating grub...</source>
        <translation>Ενημέρωση του grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1188"/>
        <source>About %1</source>
        <translation>Περί του %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1189"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Πρόγραμμα για τις επιλογές εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1193"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1194"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1215"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1533"/>
        <source>Running in a Virtual Machine</source>
        <translation>Εκτέλεση σε εικονική μηχανή</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Το τρέχον σύστημα εκτελείται σε εικονική μηχανή,
Η αρχική οθόνη εκκίνησης του plymouth θα λειτουργήσει με περιορισμένο τρόπο, και δεν θα μπορείτε να κάνετε προεπισκόπηση  θέματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Plymouth packages not installed</source>
        <translation>Τα πακέτα του plymouth δεν έχουν εγκατασταθεί</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1234"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Τα πακέτα του plymouth δεν είναι εγκατεστημένα.
Θέλετε να προχωρήσετε και να τα εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1260"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Εικόνες (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Log not found</source>
        <translation>Δεν βρέθηκε αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Could not find log at </source>
        <translation>Δεν ήταν δυνατή η εύρεση του αρχείου αλλαγών σε </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1409"/>
        <source>Edit UEFI Boot Entries</source>
        <translation>Επεξεργασία καταχωρήσεων εκκίνησης UEFI</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation>Για να αλλάξετε τη σειρά εκκίνησης μπορείτε να χρησιμοποιήσετε τα κουμπιά Επάνω/Κάτω ή να σύρετε και να αποθέσετε τις καταχωρήσεις.
- Οι καταχωρήσεις εμφανίζονται με τη σειρά εκκίνησης.
- Οι γραμμές με γκρίζο χρώμα είναι ανενεργές.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1423"/>
        <location filename="../mainwindow.cpp" line="1471"/>
        <source>Set ac&amp;tive</source>
        <translation>Ορισμός ε&amp;νεργού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>&amp;Add entry</source>
        <translation>Προσ&amp;θήκη καταχώρησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1425"/>
        <source>Boot &amp;next</source>
        <translation>Εκκίνηση ε&amp;πόμενου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1636"/>
        <source>Could not retrieve UUID for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1644"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Εισάγετε κωδικό πρόσβασης για να ξεκλειδώσετε τη κρυπτογραφημένη κατάτμηση %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1649"/>
        <source>Password entry cancelled or empty for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1655"/>
        <source>Could not open %1 LUKS container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <location filename="../mainwindow.cpp" line="1426"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>A process is still running. Do you really want to quit?</source>
        <translation>Μια διαδικασία εξακολουθεί να εκτελείται. Θέλετε σίγουρα να κλείσετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Live System Detected</source>
        <translation>Ανιχνεύθηκε σύστημα.live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>You are currently running a live system. Would you like to modify the boot options for the live system or for an installed system?</source>
        <translation>Αυτή τη στιγμή χρησιμοποιείτε σύστημα live. Θέλετε να τροποποιήσετε τις επιλογές εκκίνησης για το σύστημα live.ή για ένα εγκατεστημένο σύστημα;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Live System</source>
        <translation>Σύστημα live</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Installed System</source>
        <translation>Εγκατεστημένο σύστημα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Failed to update package sources.</source>
        <translation>Απέτυχε η ενημέρωση των πακέτων.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>Installing packages:</source>
        <translation>Εγκατάσταση πακέτων:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Success</source>
        <translation>Επιτυχία</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="533"/>
        <source>Bootsplash installed successfully.</source>
        <translation>Η αρχική οθόνη εκκίνησης εγκαταστάθηκε με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Failed to create temporary file.</source>
        <translation>Απέτυχε η δημιουργία του προσωρινού αρχείου.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1171"/>
        <source>You are currently running in live mode with the &apos;toram&apos; option. Please remember to save the persistence file or remaster, otherwise any changes made will be lost.</source>
        <translation>Αυτή τη στιγμή βρίσκεστε σε λειτουργία live με την επιλογή &apos;toram&apos;. Παρακαλώ θυμηθείτε να αποθηκεύσετε το αρχείο persistence ή το remaster, διαφορετικά οι αλλαγές που θα γίνουν θα χαθούν.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1173"/>
        <source>Your changes have been successfully applied.</source>
        <translation>Οι αλλαγές σας εφαρμόστηκαν με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1174"/>
        <source>Operation Complete</source>
        <translation>Η διαδικασία ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1259"/>
        <source>Select image to display in bootloader</source>
        <translation>Επιλέξτε την εικόνα που θα εμφανίζει ο φορτωτής εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1383"/>
        <source>Boot Log</source>
        <translation>Αρχείο εκκίνησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1427"/>
        <source>Move &amp;down</source>
        <translation>Μετακίνηση &amp;κάτω</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1428"/>
        <source>&amp;Remove entry</source>
        <translation>Α&amp;φαίρεση καταχώρησης</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1429"/>
        <source>Re&amp;set next</source>
        <translation>Επαναφο&amp;ρά επόμενου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1430"/>
        <source>Change &amp;timeout</source>
        <translation>Αλλαγή &amp;χρονικής διάρκειας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Move &amp;up</source>
        <translation>Μετακίνηση &amp;επάνω</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1435"/>
        <location filename="../mainwindow.cpp" line="1443"/>
        <source>not set, will boot using list order</source>
        <translation>δεν ορίστηκε, θα εκκινήσει με τη σειρά της λίστας</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1468"/>
        <source>Set &amp;inactive</source>
        <translation>Ορισμός ανενε&amp;ργού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1522"/>
        <source>Needs reboot</source>
        <translation>Χρειάζεται επανεκκίνηση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1523"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Το plymouth μόλις εγκαταστάθηκε, ίσως χρειαστεί να επανεκκινήσετε για να έχετε τη δυνατότητα προεπισκοπήσεων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Click to select theme</source>
        <translation>Κάντε κλικ για να επιλέξετε θέμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1603"/>
        <source>Select GRUB theme</source>
        <translation>Επιλέξτε θέμα του GRUB</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Πρόγραμμα επιλογής των συνηθισμένων προτιμήσεων της εκκίνησης</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="55"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="56"/>
        <location filename="../about.cpp" line="65"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="57"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <location filename="../main.cpp" line="90"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Φαίνεται ότι έχετε συνδεθεί ως root, αποσυνδεθείτε και συνδεθείτε ως κανονικός χρήστης για να χρησιμοποιήσετε αυτό το πρόγραμμα.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>You must run this program with admin access.</source>
        <translation>Πρέπει να εκτελέσετε αυτό το πρόγραμμα με πρόσβαση διαχειριστή.</translation>
    </message>
</context>
</TS>
